import { JsonRpcServer, Event } from "@theia/core";
export declare namespace ISloggerServerTypes {
    enum NotifcationData {
        OK = 0,
        ERROR = 1,
        STOPPED = 2
    }
    class ImportFileResult {
        resultCode: ImportFileResultCode;
    }
    enum ImportFileResultCode {
        OK = 0,
        UNKNOWN_FAILURE = 1
    }
    class ChangeQueryResult {
    }
    class GetEventsFromToResult {
        events: Events[];
    }
    class Events {
        rowid: number;
        timestamp: number;
        data: Array<[string, string]>;
    }
    class ClearDataResult {
    }
    class OnQueryChangedResult {
    }
    class OnQueryChangedNotification {
        resultSize: number;
        notifcationData?: NotifcationData;
    }
    class OnImportFileResult {
    }
    class OnImportFileNotification {
        numberEvents: number;
        distinctFields: string[];
        notifcationData?: NotifcationData;
    }
}
export declare const SLOGGER_SERVICE_WS_PATH = "/services/slogger-service";
export declare const ISloggerServer: unique symbol;
export interface ISloggerServer extends JsonRpcServer<ISloggerClient> {
    importFile(path: string): Promise<ISloggerServerTypes.ImportFileResult>;
    changeQuery(path: string, query: string): Promise<ISloggerServerTypes.ChangeQueryResult>;
    getEventsFromTo(fromIndex: number, toIndex: number): Promise<ISloggerServerTypes.GetEventsFromToResult>;
    clearData(): Promise<ISloggerServerTypes.ClearDataResult>;
    registerOnQueryChanged(): void;
    registerOnImportFile(): void;
}
export declare const ISloggerClient: unique symbol;
export interface ISloggerClient {
    onQueryChanged(event: ISloggerServerTypes.OnQueryChangedNotification): void;
    onImportFile(event: ISloggerServerTypes.OnImportFileNotification): void;
}
export declare class DispatchingSLoggerClient implements ISloggerClient {
    readonly clients: Set<ISloggerClient>;
    constructor();
    push(client: ISloggerClient): void;
    remove(client: ISloggerClient): void;
    onQueryChanged(event: ISloggerServerTypes.OnQueryChangedNotification): void;
    onImportFile(event: ISloggerServerTypes.OnImportFileNotification): void;
}
export declare class SloggerServerWatcher {
    private onImportFileEmitter;
    private onQueryChangedEmitter;
    getSloggerClient(): ISloggerClient;
    get onImportFile(): Event<ISloggerServerTypes.OnImportFileNotification>;
    get onQueryChanged(): Event<ISloggerServerTypes.OnQueryChangedNotification>;
}
//# sourceMappingURL=slogger-protocol.d.ts.map