"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var inversify_1 = require("inversify");
var slogger_service_starter_1 = require("./slogger-service-starter");
var backend_application_1 = require("@theia/core/lib/node/backend-application");
var trace_protocol_1 = require("../common/trace-protocol");
var slogger_log4js_1 = require("./slogger-log4js");
var slogger_protocol_1 = require("../common/slogger-protocol");
var slogger_server_1 = require("./slogger-server");
var core_1 = require("@theia/core");
var trace_server_1 = require("./trace-server");
exports.default = new inversify_1.ContainerModule(function (bind) {
    /********* SLOGGER-SECTION START ***********/
    bind(slogger_protocol_1.DispatchingSLoggerClient).toSelf().inSingletonScope();
    bind(slogger_protocol_1.ISloggerServer).to(slogger_server_1.SloggerRpcBridge).inSingletonScope().onActivation(function (context, server) {
        var client = context.container.get(slogger_protocol_1.DispatchingSLoggerClient);
        server.setClient(client);
        return server;
    });
    bind(core_1.ConnectionHandler).toDynamicValue(function (ctx) {
        return new core_1.JsonRpcConnectionHandler(slogger_protocol_1.SLOGGER_SERVICE_WS_PATH, function (client) {
            var dispatcher = ctx.container.get(slogger_protocol_1.DispatchingSLoggerClient);
            dispatcher.push(client);
            client.onDidCloseConnection(function () { return dispatcher.remove(client); });
            return ctx.container.get(slogger_protocol_1.ISloggerServer);
        });
    }).inSingletonScope();
    bind(backend_application_1.BackendApplicationContribution).to(slogger_service_starter_1.SloggerServiceStarter);
    /********* SLOGGER-SECTION END ***********/
    /********* TRACING-SECTION START ***********/
    // Setup the Trace Server for remote logging (logs geerated from UI)
    bind(trace_server_1.TraceServer).toSelf().inSingletonScope();
    bind(trace_protocol_1.ITracer).toService(trace_server_1.TraceServer);
    bind(core_1.ConnectionHandler).toDynamicValue(function (ctx) {
        return new core_1.JsonRpcConnectionHandler(trace_protocol_1.TRACER_SERVICE_WS_PATH, function () {
            return ctx.container.get(trace_protocol_1.ITracer);
        });
    }).inSingletonScope();
    // Setup the Logger (for *.slog files)
    bind(slogger_log4js_1.TracerNode).toSelf().inSingletonScope();
    /********* TRACING-SECTION END ***********/
});
//# sourceMappingURL=core-backend-module.js.map