"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var log4js_1 = require("log4js");
var moment = require("moment");
var inversify_1 = require("inversify");
var trace_protocol_1 = require("../common/trace-protocol");
var TracerNode = /** @class */ (function () {
    function TracerNode() {
        var _this = this;
        this.APPLICATION = "slogger-ui";
        log4js_1.addLayout('json', function (config) {
            return function (logEvent) {
                var _a, _b;
                return JSON.stringify({
                    ts: (logEvent.startTime).toISOString().slice(0, -1),
                    app: _this.APPLICATION,
                    context: (_b = (_a = logEvent.context) === null || _a === void 0 ? void 0 : _a.type) !== null && _b !== void 0 ? _b : "plain",
                    component: logEvent.categoryName,
                    loglevel: logEvent.level.levelStr,
                    payload: (function (ctx) {
                        if (ctx === null || ctx === undefined)
                            return { message: logEvent.data[0] };
                        else
                            return JSON.parse(logEvent.data[0]);
                    })(logEvent.context.type)
                });
            };
        });
        log4js_1.configure({
            appenders: {
                file: { type: 'file',
                    filename: this.APPLICATION + "_" + moment().format('YYYY-MM-DD_hh-mm') + ".slog",
                    layout: { type: 'json', separator: ',' } },
                out: { type: 'stdout' }
            },
            categories: { default: { appenders: ['file', 'out'], level: 'debug' } }
        });
        this.logger = log4js_1.getLogger();
    }
    TracerNode.prototype.logIpcCall = function (id, type, name, params) {
        this.logger.addContext('type', 'ipc');
        if (type === trace_protocol_1.IpcMessageType.Error) {
            this.error(JSON.stringify({ callid: id, msg_type: type, msg_name: name, params: params }));
        }
        else {
            this.info(JSON.stringify({ callid: id, msg_type: type, msg_name: name, params: params }));
        }
        this.logger.removeContext('type');
    };
    TracerNode.prototype.logState = function (state) {
        this.logger.addContext('type', 'state');
        this.info(JSON.stringify({ message: state }));
        this.logger.removeContext('type');
    };
    TracerNode.prototype.info = function (message) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        this.logger.info(message);
    };
    TracerNode.prototype.error = function (message) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        this.logger.error(message);
    };
    TracerNode.prototype.warn = function (message) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        this.logger.warn(message);
    };
    TracerNode = __decorate([
        inversify_1.injectable(),
        __metadata("design:paramtypes", [])
    ], TracerNode);
    return TracerNode;
}());
exports.TracerNode = TracerNode;
//# sourceMappingURL=slogger-log4js.js.map