"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var inversify_1 = require("inversify");
var slogger_protocol_1 = require("../common/slogger-protocol");
var slogger_service_pb_1 = require("../api/slogger_service_pb");
var slogger_service_grpc_pb_1 = require("../api/slogger_service_grpc_pb");
var trace_protocol_1 = require("../common/trace-protocol");
var grpc = require("@grpc/grpc-js");
var slogger_log4js_1 = require("./slogger-log4js");
var SloggerRpcBridge = /** @class */ (function () {
    function SloggerRpcBridge() {
        this.grpcProxy = new slogger_service_grpc_pb_1.SLoggerServiceClient("localhost:50051", grpc.credentials.createInsecure());
    }
    SloggerRpcBridge.prototype.init = function () {
        this.registerOnImportFile();
        this.registerOnQueryChanged();
    };
    SloggerRpcBridge.prototype.importFile = function (path) {
        var self = this;
        return new Promise(function (resolve, reject) {
            var request = new slogger_service_pb_1.ImportFileRequest();
            request.setPath(path);
            self.logger.logIpcCall(0, trace_protocol_1.IpcMessageType.Request, "slogger-service.importFile", request.toObject());
            self.grpcProxy.importFile(request, function (error, response) {
                if (error) {
                    reject(new Error(error.message));
                }
                else {
                    var obj = response.toObject();
                    self.logger.logIpcCall(0, trace_protocol_1.IpcMessageType.Response, "slogger-service.importFile", obj);
                    var result = new slogger_protocol_1.ISloggerServerTypes.ImportFileResult();
                    result.resultCode = obj.resultcode;
                    resolve(result);
                }
            });
        });
    };
    SloggerRpcBridge.prototype.changeQuery = function (queryRootDirPath, queryName) {
        var self = this;
        return new Promise(function (resolve, reject) {
            var request = new slogger_service_pb_1.QueryRequest();
            request.setQueryname(queryName);
            request.setQueryrootdirpath(queryRootDirPath);
            self.logger.logIpcCall(0, trace_protocol_1.IpcMessageType.Request, "slogger-service.changeQuery", request);
            self.grpcProxy.changeQuery(request, function (error, response) {
                if (error) {
                    self.logger.logIpcCall(0, trace_protocol_1.IpcMessageType.Error, "slogger-service.changeQuery", { error: error.message });
                    reject(new Error(error.message));
                }
                else {
                    var obj = response.toObject();
                    self.logger.logIpcCall(0, trace_protocol_1.IpcMessageType.Response, "slogger-service.changeQuery", obj);
                    var result = new slogger_protocol_1.ISloggerServerTypes.ChangeQueryResult();
                    resolve(result);
                }
            });
        });
    };
    SloggerRpcBridge.prototype.getEventsFromTo = function (fromIndex, toIndex) {
        var self = this;
        return new Promise(function (resolve, reject) {
            var request = new slogger_service_pb_1.GetEventsFromToRequest();
            request.setFromindex(fromIndex);
            request.setToindex(toIndex);
            self.logger.logIpcCall(0, trace_protocol_1.IpcMessageType.Request, "slogger-service.getEventsFromTo", request.toObject());
            self.grpcProxy.getEventsFromTo(request, function (error, response) {
                if (error) {
                    self.logger.logIpcCall(0, trace_protocol_1.IpcMessageType.Error, "slogger-service.getEventsFromTo", { error: error.message });
                    reject(new Error(error.message));
                }
                else {
                    var obj = response.toObject();
                    self.logger.logIpcCall(0, trace_protocol_1.IpcMessageType.Response, "slogger-service.getEventsFromTo", { size: obj.eventsList.length });
                    var result = new slogger_protocol_1.ISloggerServerTypes.GetEventsFromToResult();
                    var events = obj.eventsList.map(function (e) {
                        var event = new slogger_protocol_1.ISloggerServerTypes.Events();
                        event.rowid = e.rowid;
                        event.timestamp = e.timestamp;
                        event.data = e.dataMap;
                        return event;
                    });
                    result.events = events;
                    resolve(result);
                }
            });
        });
    };
    SloggerRpcBridge.prototype.clearData = function () {
        var self = this;
        return new Promise(function (resolve, reject) {
            var request = new slogger_service_pb_1.ClearDataRequest();
            self.logger.logIpcCall(0, trace_protocol_1.IpcMessageType.Request, "slogger-service.clearData", request.toObject());
            self.grpcProxy.clearData(request, function (error, response) {
                if (error) {
                    self.logger.logIpcCall(0, trace_protocol_1.IpcMessageType.Error, "slogger-service.clearData", { error: error.message });
                    reject(new Error(error.message));
                }
                else {
                    var obj = response.toObject();
                    self.logger.logIpcCall(0, trace_protocol_1.IpcMessageType.Response, "slogger-service.clearData", obj);
                    var result = new slogger_protocol_1.ISloggerServerTypes.ClearDataResult();
                    resolve(result);
                }
            });
        });
    };
    SloggerRpcBridge.prototype.registerOnQueryChanged = function () {
        this.logger.logIpcCall(0, trace_protocol_1.IpcMessageType.Request, "slogger-service.registerOnQueryChanged", {});
        var call = this.grpcProxy.registerOnQueryChanged(new slogger_service_pb_1.OnQueryChangedRequest());
        var self = this;
        call.on('data', function (notification) {
            var _a;
            var obj = notification.toObject();
            var result = new slogger_protocol_1.ISloggerServerTypes.OnQueryChangedNotification();
            result.resultSize = obj.resultsize;
            result.notifcationData = slogger_protocol_1.ISloggerServerTypes.NotifcationData.OK;
            self.logger.logIpcCall(0, trace_protocol_1.IpcMessageType.Notification, "slogger-service.registerOnQueryChanged", result);
            (_a = self.client) === null || _a === void 0 ? void 0 : _a.onQueryChanged(result);
        });
        call.on('error', function (error) {
            var _a;
            var result = new slogger_protocol_1.ISloggerServerTypes.OnQueryChangedNotification();
            result.notifcationData = slogger_protocol_1.ISloggerServerTypes.NotifcationData.ERROR;
            self.logger.logIpcCall(0, trace_protocol_1.IpcMessageType.Notification, "slogger-service.registerOnQueryChanged", result);
            (_a = self.client) === null || _a === void 0 ? void 0 : _a.onQueryChanged(result);
        });
        call.on('end', function () {
            var _a;
            var result = new slogger_protocol_1.ISloggerServerTypes.OnQueryChangedNotification();
            result.notifcationData = slogger_protocol_1.ISloggerServerTypes.NotifcationData.STOPPED;
            self.logger.logIpcCall(0, trace_protocol_1.IpcMessageType.Notification, "slogger-service.registerOnQueryChanged", result);
            (_a = self.client) === null || _a === void 0 ? void 0 : _a.onQueryChanged(result);
        });
    };
    SloggerRpcBridge.prototype.registerOnImportFile = function () {
        this.logger.logIpcCall(0, trace_protocol_1.IpcMessageType.Request, "slogger-service.registerOnImportFile", {});
        var call = this.grpcProxy.registerOnImportFile(new slogger_service_pb_1.OnImportFileRequest());
        var self = this;
        call.on('data', function (notification) {
            var _a;
            var obj = notification.toObject();
            var result = new slogger_protocol_1.ISloggerServerTypes.OnImportFileNotification();
            result.numberEvents = obj.numberevents;
            result.distinctFields = obj.distinctfieldsList;
            result.notifcationData = slogger_protocol_1.ISloggerServerTypes.NotifcationData.OK;
            self.logger.logIpcCall(0, trace_protocol_1.IpcMessageType.Notification, "slogger-service.registerOnImportFile", result);
            (_a = self.client) === null || _a === void 0 ? void 0 : _a.onImportFile(result);
        });
        call.on('error', function (error) {
            var _a;
            var result = new slogger_protocol_1.ISloggerServerTypes.OnImportFileNotification();
            result.notifcationData = slogger_protocol_1.ISloggerServerTypes.NotifcationData.ERROR;
            self.logger.logIpcCall(0, trace_protocol_1.IpcMessageType.Notification, "slogger-service.registerOnImportFile", result);
            (_a = self.client) === null || _a === void 0 ? void 0 : _a.onImportFile(result);
        });
        call.on('end', function () {
            var _a;
            var result = new slogger_protocol_1.ISloggerServerTypes.OnImportFileNotification();
            result.notifcationData = slogger_protocol_1.ISloggerServerTypes.NotifcationData.STOPPED;
            self.logger.logIpcCall(0, trace_protocol_1.IpcMessageType.Notification, "slogger-service.registerOnImportFile", result);
            (_a = self.client) === null || _a === void 0 ? void 0 : _a.onImportFile(result);
        });
    };
    SloggerRpcBridge.prototype.dispose = function () {
        /* no op */
    };
    SloggerRpcBridge.prototype.setClient = function (client) {
        console.log("**** SloggerRpcBridge.setClient " + JSON.stringify(client));
        this.client = client;
    };
    __decorate([
        inversify_1.inject(slogger_log4js_1.TracerNode),
        __metadata("design:type", slogger_log4js_1.TracerNode)
    ], SloggerRpcBridge.prototype, "logger", void 0);
    __decorate([
        inversify_1.postConstruct(),
        __metadata("design:type", Function),
        __metadata("design:paramtypes", []),
        __metadata("design:returntype", void 0)
    ], SloggerRpcBridge.prototype, "init", null);
    SloggerRpcBridge = __decorate([
        inversify_1.injectable(),
        __metadata("design:paramtypes", [])
    ], SloggerRpcBridge);
    return SloggerRpcBridge;
}());
exports.SloggerRpcBridge = SloggerRpcBridge;
//# sourceMappingURL=slogger-server.js.map