import { ContainerModule } from 'inversify';
import { ITracer, TRACER_SERVICE_WS_PATH } from '../common/trace-protocol';
import { ISloggerServer, SLOGGER_SERVICE_WS_PATH, SloggerServerWatcher } from '../common/slogger-protocol';

import { WebSocketConnectionProvider } from '@theia/core/lib/browser'
import { SloggerServiceJsonRpcProxy } from './slogger-jsonrpc-proxy';

export default new ContainerModule(bind => {

    bind(SloggerServiceJsonRpcProxy).toSelf().inSingletonScope();

    bind(SloggerServerWatcher).toSelf().inSingletonScope();

    bind(ISloggerServer).toDynamicValue(ctx => {
        const sloggerWatcher = ctx.container.get(SloggerServerWatcher);
        const connection = ctx.container.get(WebSocketConnectionProvider);
        const target = connection.createProxy<ISloggerServer>(SLOGGER_SERVICE_WS_PATH, sloggerWatcher.getSloggerClient());
        return target;
    }).inSingletonScope();

    bind(ITracer).toDynamicValue( ctx => {
        const provider = ctx.container.get(WebSocketConnectionProvider);
        return provider.createProxy<ITracer>(TRACER_SERVICE_WS_PATH);
    }).inSingletonScope();

});