import { injectable, inject } from 'inversify';
import { ISloggerServerTypes, ISloggerServer } from "../common/slogger-protocol";
import { ITracer } from '../common/trace-protocol';

@injectable()
export class SloggerServiceJsonRpcProxy {

    @inject(ISloggerServer)
    protected readonly server: ISloggerServer;

    @inject(ITracer) protected readonly logger: ITracer;

    importFile(path: string): Promise<ISloggerServerTypes.ImportFileResult> {
        this.logger.info("SloggerServiceJsonRpcProxy.importFile");
        return this.server.importFile(path);
    }

    changeQuery(path: string, query: string): Promise<ISloggerServerTypes.ChangeQueryResult> {
        this.logger.info("SloggerServiceJsonRpcProxy.changeQuery");
        return this.server.changeQuery(path, query);
    }

    getEventsFromTo(fromIndex: number, toIndex: number): Promise<ISloggerServerTypes.GetEventsFromToResult> {
       this.logger.info("SloggerServiceJsonRpcProxy.getEventsFromTo");
       return this.server.getEventsFromTo(fromIndex, toIndex);
    }

    clearData(): Promise<ISloggerServerTypes.ClearDataResult> {
        this.logger.info("SloggerServiceJsonRpcProxy.clearData");
        return this.server.clearData();
    }
}

