import { injectable } from 'inversify';

export const TRACER_SERVICE_WS_PATH = '/services/tracer-service';

export const ITracer = Symbol('ITracer');

export enum IpcMessageType {
    Request = "Request",
    Response = "Response",
    Notification = "Notification",
    Error = "Error"
}

export interface ITracer {

    info(message: string, ...args: any[]): void;

    error(message: string, ...args: any[]): void;

    warn(message: string, ...args: any[]): void;

    logIpcCall(id: number, type: IpcMessageType, name: string, params: any): void;

    logState(state: any) : void;
}

@injectable()
export class TracerDefault implements ITracer {

    logState(state: any): void {
        console.info("state ", state);
    }

    logIpcCall(id: number, type: IpcMessageType, name: string, params: any): void {
        console.info("ipc ", type, name, params);
    }

    info(message: string, ...args: any[]): void {
        console.info(message, args);
    }

    error(message: string, ...args: any[]): void {
        console.error(message, args);
    }

    warn(message: string, ...args: any[]): void {
        console.warn(message, args);
    }

}

