import { ContainerModule } from 'inversify';
import { SloggerServiceStarter } from './slogger-service-starter';
import { BackendApplicationContribution } from '@theia/core/lib/node/backend-application';

import { ITracer, TRACER_SERVICE_WS_PATH } from '../common/trace-protocol';
import { TracerNode } from './slogger-log4js';
import { ISloggerServer, ISloggerClient, SLOGGER_SERVICE_WS_PATH, DispatchingSLoggerClient } from '../common/slogger-protocol';
import { SloggerRpcBridge } from './slogger-server';
import { ConnectionHandler, JsonRpcConnectionHandler } from '@theia/core';
import { TraceServer } from './trace-server';

export default new ContainerModule(bind => {

    /********* SLOGGER-SECTION START ***********/
    bind(DispatchingSLoggerClient).toSelf().inSingletonScope();

    bind(ISloggerServer).to(SloggerRpcBridge).inSingletonScope().onActivation( (context, server: ISloggerServer) => {
        const client = context.container.get(DispatchingSLoggerClient);
        server.setClient(client);
        return server;
    });
    
    bind(ConnectionHandler).toDynamicValue(ctx => 
        new JsonRpcConnectionHandler<ISloggerClient>(SLOGGER_SERVICE_WS_PATH, client => {
            const dispatcher = ctx.container.get(DispatchingSLoggerClient);
            dispatcher.push(client);
            client.onDidCloseConnection( () => dispatcher.remove(client));
            return ctx.container.get<ISloggerServer>(ISloggerServer);
        })
    ).inSingletonScope();

    bind(BackendApplicationContribution).to(SloggerServiceStarter);
    /********* SLOGGER-SECTION END ***********/

    /********* TRACING-SECTION START ***********/

    // Setup the Trace Server for remote logging (logs geerated from UI)
    bind(TraceServer).toSelf().inSingletonScope();    
    bind(ITracer).toService(TraceServer);

    bind(ConnectionHandler).toDynamicValue(ctx =>
        new JsonRpcConnectionHandler(TRACER_SERVICE_WS_PATH, () =>
            ctx.container.get(ITracer)
        )
    ).inSingletonScope();

    // Setup the Logger (for *.slog files)
    bind(TracerNode).toSelf().inSingletonScope();
    /********* TRACING-SECTION END ***********/

});